# xbim-flex
This is the XBIM Flex Swagger service where you can explore the REST API for the platform.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v1
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://xbim.net](https://xbim.net)

## Requirements.

Python >= 3.6

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import xbim_flex.aim
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import xbim_flex.aim
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import xbim_flex.aim
from pprint import pprint
from xbim_flex.aim.api import admin_api
from xbim_flex.aim.model.db_update import DbUpdate
# Defining the host is optional and defaults to https://internal.xbim-dev.net
# See configuration.py for a list of all supported configuration parameters.
configuration = aim.Configuration(
    host = "https://internal.xbim-dev.net"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure OAuth2 access token for authorization: oauth2
configuration = aim.Configuration(
    host = "https://internal.xbim-dev.net"
)
configuration.access_token = 'YOUR_ACCESS_TOKEN'


# Enter a context with an instance of the API client
with aim.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = admin_api.AdminApi(api_client)
    region = "UK" # str | The data center region the data resides in (default to "UK")

    try:
        # Lists the Database schema updates already installed
        api_response = api_instance.admin_applied_updates(region)
        pprint(api_response)
    except aim.ApiException as e:
        print("Exception when calling AdminApi->admin_applied_updates: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://internal.xbim-dev.net*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AdminApi* | [**admin_applied_updates**](docs/AdminApi.md#admin_applied_updates) | **GET** /{region}/aim/admin/schema/AppliedUpdates | Lists the Database schema updates already installed
*AdminApi* | [**admin_flush_caches**](docs/AdminApi.md#admin_flush_caches) | **POST** /{region}/aim/admin/schema/FlushCaches | Flushes the Flex caches
*AdminApi* | [**admin_get_is_current**](docs/AdminApi.md#admin_get_is_current) | **GET** /{region}/aim/admin/schema/IsCurrent | Returns a flag indicating if the database schema requires an upgrade
*AdminApi* | [**admin_pending_updates**](docs/AdminApi.md#admin_pending_updates) | **GET** /{region}/aim/admin/schema/PendingUpdates | Lists the Database schema updates required
*AdminApi* | [**admin_update_schema**](docs/AdminApi.md#admin_update_schema) | **POST** /{region}/aim/admin/schema/UpdateSchema | Updates the Database schemas to the latest version
*ApplicationsApi* | [**applications_get_by_tenantid**](docs/ApplicationsApi.md#applications_get_by_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Applications | Returns the EntitySet Applications
*ApplicationsApi* | [**applications_get_single_by_applicationid_and_tenantid**](docs/ApplicationsApi.md#applications_get_single_by_applicationid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Applications({ApplicationId}) | Returns the entity with the key from Applications
*AssembliesApi* | [**assemblies_add_document_by_assetmodelid_and_entityid_and_tenantid**](docs/AssembliesApi.md#assemblies_add_document_by_assetmodelid_and_entityid_and_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Assemblies(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId})/DocumentEntities | Adds a new document to a model entity
*AssembliesApi* | [**assemblies_as_of_by_date_and_tenantid**](docs/AssembliesApi.md#assemblies_as_of_by_date_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Assemblies/AsOf(date&#x3D;{date}) | 
*AssembliesApi* | [**assemblies_get_available_properties_by_assetid_and_tenantid**](docs/AssembliesApi.md#assemblies_get_available_properties_by_assetid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Assemblies/GetAvailableProperties(assetId&#x3D;{assetId}) | Gets the Properties available on this Model
*AssembliesApi* | [**assemblies_get_by_tenantid**](docs/AssembliesApi.md#assemblies_get_by_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Assemblies | Returns the EntitySet Assemblies
*AssembliesApi* | [**assemblies_get_single_entity_by_assetmodelid_and_entityid_and_tenantid**](docs/AssembliesApi.md#assemblies_get_single_entity_by_assetmodelid_and_entityid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Assemblies(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId}) | 
*AssembliesApi* | [**assemblies_patch_by_assetmodelid_and_entityid_and_tenantid**](docs/AssembliesApi.md#assemblies_patch_by_assetmodelid_and_entityid_and_tenantid) | **PATCH** /{region}/aim/odata/{tenantId}/Assemblies(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId}) | 
*AssembliesApi* | [**assemblies_post_by_tenantid**](docs/AssembliesApi.md#assemblies_post_by_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Assemblies | Post a new entity to EntitySet Assemblies
*AssetsApi* | [**assets_assign_by_tenantid_and_assetid**](docs/AssetsApi.md#assets_assign_by_tenantid_and_assetid) | **POST** /{region}/aim/odata/{tenantId}/Assets({AssetId})/Roles.Assign | Assigns a user to the given role on the asset
*AssetsApi* | [**assets_delete_by_assetid_and_tenantid**](docs/AssetsApi.md#assets_delete_by_assetid_and_tenantid) | **DELETE** /{region}/aim/odata/{tenantId}/Assets({AssetId}) | Archive an Asset and and models for future deletion
*AssetsApi* | [**assets_get_by_tenantid**](docs/AssetsApi.md#assets_get_by_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Assets | Returns the EntitySet Assets
*AssetsApi* | [**assets_get_single_by_assetid_and_tenantid**](docs/AssetsApi.md#assets_get_single_by_assetid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Assets({AssetId}) | Returns the entity with the key from Assets
*AssetsApi* | [**assets_member_access_by_assetid_and_tenantid**](docs/AssetsApi.md#assets_member_access_by_assetid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Assets({AssetId})/MemberAccess | Gets the list of users with access to this item and their permissions
*AssetsApi* | [**assets_permissions_by_assetid_and_tenantid**](docs/AssetsApi.md#assets_permissions_by_assetid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Assets({AssetId})/Permissions | Gets the effective permissions for this current user
*AssetsApi* | [**assets_post_by_tenantid**](docs/AssetsApi.md#assets_post_by_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Assets | Post a new entity to EntitySet Assets
*AssetsApi* | [**assets_revoke_by_tenantid_and_assetid**](docs/AssetsApi.md#assets_revoke_by_tenantid_and_assetid) | **POST** /{region}/aim/odata/{tenantId}/Assets({AssetId})/Roles.Revoke | Revokes a user from the given role on the asset
*AssetsApi* | [**assets_roles_by_assetid_and_tenantid**](docs/AssetsApi.md#assets_roles_by_assetid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Assets({AssetId})/Roles | Gets the roles for the given Asset
*AttributesApi* | [**attributes_change_data_type_by_assetmodelid_and_definitionid_and_tenantid**](docs/AttributesApi.md#attributes_change_data_type_by_assetmodelid_and_definitionid_and_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Attributes(AssetModelId&#x3D;{assetModelId},AttributeDefinitionId&#x3D;{definitionId})/ChangeDataType() | Change the underlying data type for the attribute, migrating any existing data where possible
*AttributesApi* | [**attributes_get_by_assetmodelid_and_definitionid_and_tenantid**](docs/AttributesApi.md#attributes_get_by_assetmodelid_and_definitionid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Attributes(AssetModelId&#x3D;{assetModelId},AttributeDefinitionId&#x3D;{definitionId}) | Operation to interrogate a single attribute definition
*AttributesApi* | [**attributes_get_by_tenantid**](docs/AttributesApi.md#attributes_get_by_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Attributes | Returns the EntitySet Attributes
*AttributesApi* | [**attributes_get_model_values_by_assetmodelid_and_definitionid_and_tenantid**](docs/AttributesApi.md#attributes_get_model_values_by_assetmodelid_and_definitionid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Attributes(AssetModelId&#x3D;{assetModelId},AttributeDefinitionId&#x3D;{definitionId})/GetModelValues() | Gets a sample of the attribute values for the definition
*AttributesApi* | [**attributes_get_values_for_entity_by_assetmodelid_and_entityid_and_tenantid**](docs/AttributesApi.md#attributes_get_values_for_entity_by_assetmodelid_and_entityid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Attributes/GetValuesForEntity(assetModelId&#x3D;{assetModelId},entityId&#x3D;{entityId}) | Gets the unimported attribute values for an entity from the source model
*AttributesApi* | [**attributes_import_by_assetmodelid_and_definitionid_and_tenantid**](docs/AttributesApi.md#attributes_import_by_assetmodelid_and_definitionid_and_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Attributes(AssetModelId&#x3D;{assetModelId},AttributeDefinitionId&#x3D;{definitionId})/Import() | Imports attribute values from the source model file
*AttributesApi* | [**attributes_patch_by_assetmodelid_and_definitionid_and_tenantid**](docs/AttributesApi.md#attributes_patch_by_assetmodelid_and_definitionid_and_tenantid) | **PATCH** /{region}/aim/odata/{tenantId}/Attributes(AssetModelId&#x3D;{assetModelId},AttributeDefinitionId&#x3D;{definitionId}) | Update an AttributeDefinition for a model
*AttributesApi* | [**attributes_post_by_tenantid**](docs/AttributesApi.md#attributes_post_by_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Attributes | Creates a new AttributeDefinition for a model
*ComponentTypesApi* | [**component_types_add_document_by_assetmodelid_and_entityid_and_tenantid**](docs/ComponentTypesApi.md#component_types_add_document_by_assetmodelid_and_entityid_and_tenantid) | **POST** /{region}/aim/odata/{tenantId}/ComponentTypes(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId})/DocumentEntities | Adds a new document to a model entity
*ComponentTypesApi* | [**component_types_as_of_by_date_and_tenantid**](docs/ComponentTypesApi.md#component_types_as_of_by_date_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/ComponentTypes/AsOf(date&#x3D;{date}) | 
*ComponentTypesApi* | [**component_types_get_available_properties_by_assetid_and_tenantid**](docs/ComponentTypesApi.md#component_types_get_available_properties_by_assetid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/ComponentTypes/GetAvailableProperties(assetId&#x3D;{assetId}) | Gets the Properties available on this Model
*ComponentTypesApi* | [**component_types_get_by_tenantid**](docs/ComponentTypesApi.md#component_types_get_by_tenantid) | **GET** /{region}/aim/odata/{tenantId}/ComponentTypes | Returns the EntitySet ComponentTypes
*ComponentTypesApi* | [**component_types_get_single_entity_by_assetmodelid_and_entityid_and_tenantid**](docs/ComponentTypesApi.md#component_types_get_single_entity_by_assetmodelid_and_entityid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/ComponentTypes(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId}) | 
*ComponentTypesApi* | [**component_types_patch_by_assetmodelid_and_entityid_and_tenantid**](docs/ComponentTypesApi.md#component_types_patch_by_assetmodelid_and_entityid_and_tenantid) | **PATCH** /{region}/aim/odata/{tenantId}/ComponentTypes(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId}) | 
*ComponentTypesApi* | [**component_types_post_by_tenantid**](docs/ComponentTypesApi.md#component_types_post_by_tenantid) | **POST** /{region}/aim/odata/{tenantId}/ComponentTypes | Post a new entity to EntitySet ComponentTypes
*ComponentsApi* | [**components_add_document_by_assetmodelid_and_entityid_and_tenantid**](docs/ComponentsApi.md#components_add_document_by_assetmodelid_and_entityid_and_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Components(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId})/DocumentEntities | Adds a new document to a model entity
*ComponentsApi* | [**components_as_of_by_date_and_tenantid**](docs/ComponentsApi.md#components_as_of_by_date_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Components/AsOf(date&#x3D;{date}) | 
*ComponentsApi* | [**components_containing_spaces_by_assetmodelid_and_entityid_and_tenantid**](docs/ComponentsApi.md#components_containing_spaces_by_assetmodelid_and_entityid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Components(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId})/ContainingSpaces | Gets the Spaces this Component is placed in, based on Footprint data
*ComponentsApi* | [**components_get_available_properties_by_assetid_and_tenantid**](docs/ComponentsApi.md#components_get_available_properties_by_assetid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Components/GetAvailableProperties(assetId&#x3D;{assetId}) | Gets the Properties available on this Model
*ComponentsApi* | [**components_get_by_tenantid**](docs/ComponentsApi.md#components_get_by_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Components | Returns the EntitySet Components
*ComponentsApi* | [**components_get_single_entity_by_assetmodelid_and_entityid_and_tenantid**](docs/ComponentsApi.md#components_get_single_entity_by_assetmodelid_and_entityid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Components(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId}) | 
*ComponentsApi* | [**components_patch_by_assetmodelid_and_entityid_and_tenantid**](docs/ComponentsApi.md#components_patch_by_assetmodelid_and_entityid_and_tenantid) | **PATCH** /{region}/aim/odata/{tenantId}/Components(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId}) | Edit an existing component
*ComponentsApi* | [**components_post_by_tenantid**](docs/ComponentsApi.md#components_post_by_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Components | Adds a new Component to a model
*ContactsApi* | [**contacts_add_document_by_assetmodelid_and_entityid_and_tenantid**](docs/ContactsApi.md#contacts_add_document_by_assetmodelid_and_entityid_and_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Contacts(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId})/DocumentEntities | Adds a new document to a model entity
*ContactsApi* | [**contacts_as_of_by_date_and_tenantid**](docs/ContactsApi.md#contacts_as_of_by_date_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Contacts/AsOf(date&#x3D;{date}) | 
*ContactsApi* | [**contacts_get_available_properties_by_assetid_and_tenantid**](docs/ContactsApi.md#contacts_get_available_properties_by_assetid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Contacts/GetAvailableProperties(assetId&#x3D;{assetId}) | Gets the Properties available on this Model
*ContactsApi* | [**contacts_get_by_tenantid**](docs/ContactsApi.md#contacts_get_by_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Contacts | Returns the EntitySet Contacts
*ContactsApi* | [**contacts_get_single_entity_by_assetmodelid_and_entityid_and_tenantid**](docs/ContactsApi.md#contacts_get_single_entity_by_assetmodelid_and_entityid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Contacts(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId}) | 
*ContactsApi* | [**contacts_patch_by_assetmodelid_and_entityid_and_tenantid**](docs/ContactsApi.md#contacts_patch_by_assetmodelid_and_entityid_and_tenantid) | **PATCH** /{region}/aim/odata/{tenantId}/Contacts(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId}) | 
*ContactsApi* | [**contacts_post_by_tenantid**](docs/ContactsApi.md#contacts_post_by_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Contacts | Post a new entity to EntitySet Contacts
*DiagnosticsApi* | [**diagnostics_get**](docs/DiagnosticsApi.md#diagnostics_get) | **GET** /{region}/aim/core/Diagnostics | Returns the EntitySet Diagnostics
*DiagnosticsApi* | [**diagnostics_get_by_name**](docs/DiagnosticsApi.md#diagnostics_get_by_name) | **GET** /{region}/aim/core/Diagnostics(&#39;{Name}&#39;) | Returns the entity with the key from Diagnostics
*DocumentFilesApi* | [**document_files_get_file**](docs/DocumentFilesApi.md#document_files_get_file) | **GET** /{region}/aim/api/{tenantId}/documentfiles/download/{assetId}/{modelId}/{fileId} | Downloads binary file related to asset and model
*DocumentFilesApi* | [**document_files_upload_single_file**](docs/DocumentFilesApi.md#document_files_upload_single_file) | **POST** /{region}/aim/api/{tenantId}/documentfiles/upload | Uploads a document file related to a specific model
*DocumentsApi* | [**documents_add_document_by_assetmodelid_and_entityid_and_tenantid**](docs/DocumentsApi.md#documents_add_document_by_assetmodelid_and_entityid_and_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Documents(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId})/DocumentEntities | Adds a new document to a model entity
*DocumentsApi* | [**documents_as_of_by_date_and_tenantid**](docs/DocumentsApi.md#documents_as_of_by_date_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Documents/AsOf(date&#x3D;{date}) | 
*DocumentsApi* | [**documents_get_available_properties_by_assetid_and_tenantid**](docs/DocumentsApi.md#documents_get_available_properties_by_assetid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Documents/GetAvailableProperties(assetId&#x3D;{assetId}) | Gets the Properties available on this Model
*DocumentsApi* | [**documents_get_by_tenantid**](docs/DocumentsApi.md#documents_get_by_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Documents | Returns the EntitySet Documents
*DocumentsApi* | [**documents_get_single_entity_by_assetmodelid_and_entityid_and_tenantid**](docs/DocumentsApi.md#documents_get_single_entity_by_assetmodelid_and_entityid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Documents(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId}) | 
*DocumentsApi* | [**documents_patch_by_assetmodelid_and_entityid_and_tenantid**](docs/DocumentsApi.md#documents_patch_by_assetmodelid_and_entityid_and_tenantid) | **PATCH** /{region}/aim/odata/{tenantId}/Documents(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId}) | 
*DocumentsApi* | [**documents_post_by_tenantid**](docs/DocumentsApi.md#documents_post_by_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Documents | Post a new entity to EntitySet Documents
*EntitiesApi* | [**entities_add_document_by_assetmodelid_and_entityid_and_tenantid**](docs/EntitiesApi.md#entities_add_document_by_assetmodelid_and_entityid_and_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Entities(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId})/DocumentEntities | Adds a new document to a model entity
*EntitiesApi* | [**entities_as_of_by_date_and_tenantid**](docs/EntitiesApi.md#entities_as_of_by_date_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Entities/AsOf(date&#x3D;{date}) | 
*EntitiesApi* | [**entities_as_of_by_kind**](docs/EntitiesApi.md#entities_as_of_by_kind) | **GET** /{region}/aim/odata/{tenantId}/Entities/AsOf(date&#x3D;{date},entityKind&#x3D;{entityKind}) | Query a set of Entities at a point in time
*EntitiesApi* | [**entities_get_available_properties_by_assetid_and_tenantid**](docs/EntitiesApi.md#entities_get_available_properties_by_assetid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Entities/GetAvailableProperties(assetId&#x3D;{assetId}) | Gets the Properties available on this Model
*EntitiesApi* | [**entities_get_by_tenantid**](docs/EntitiesApi.md#entities_get_by_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Entities | Returns the EntitySet Entities
*EntitiesApi* | [**entities_get_single_entity_by_assetmodelid_and_entityid_and_tenantid**](docs/EntitiesApi.md#entities_get_single_entity_by_assetmodelid_and_entityid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Entities(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId}) | 
*EntitiesApi* | [**entities_lookup_by_tenantid**](docs/EntitiesApi.md#entities_lookup_by_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Entities/Guids.Lookup | Provides the xbim flex identities for a set of provided IfcGuids
*EntitiesApi* | [**entities_patch_by_assetmodelid_and_entityid_and_tenantid**](docs/EntitiesApi.md#entities_patch_by_assetmodelid_and_entityid_and_tenantid) | **PATCH** /{region}/aim/odata/{tenantId}/Entities(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId}) | 
*EntitiesApi* | [**entities_post_by_tenantid**](docs/EntitiesApi.md#entities_post_by_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Entities | Post a new entity to EntitySet Entities
*FacilitiesApi* | [**facilities_add_document_by_assetmodelid_and_entityid_and_tenantid**](docs/FacilitiesApi.md#facilities_add_document_by_assetmodelid_and_entityid_and_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Facilities(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId})/DocumentEntities | Adds a new document to a model entity
*FacilitiesApi* | [**facilities_as_of_by_date_and_tenantid**](docs/FacilitiesApi.md#facilities_as_of_by_date_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Facilities/AsOf(date&#x3D;{date}) | 
*FacilitiesApi* | [**facilities_get_available_properties_by_assetid_and_tenantid**](docs/FacilitiesApi.md#facilities_get_available_properties_by_assetid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Facilities/GetAvailableProperties(assetId&#x3D;{assetId}) | Gets the Properties available on this Model
*FacilitiesApi* | [**facilities_get_by_tenantid**](docs/FacilitiesApi.md#facilities_get_by_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Facilities | Returns the EntitySet Facilities
*FacilitiesApi* | [**facilities_get_single_entity_by_assetmodelid_and_entityid_and_tenantid**](docs/FacilitiesApi.md#facilities_get_single_entity_by_assetmodelid_and_entityid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Facilities(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId}) | 
*FacilitiesApi* | [**facilities_patch_by_assetmodelid_and_entityid_and_tenantid**](docs/FacilitiesApi.md#facilities_patch_by_assetmodelid_and_entityid_and_tenantid) | **PATCH** /{region}/aim/odata/{tenantId}/Facilities(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId}) | 
*FacilitiesApi* | [**facilities_post_by_tenantid**](docs/FacilitiesApi.md#facilities_post_by_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Facilities | Post a new entity to EntitySet Facilities
*IssuesApi* | [**issues_add_document_by_assetmodelid_and_entityid_and_tenantid**](docs/IssuesApi.md#issues_add_document_by_assetmodelid_and_entityid_and_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Issues(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId})/DocumentEntities | Adds a new document to a model entity
*IssuesApi* | [**issues_as_of_by_date_and_tenantid**](docs/IssuesApi.md#issues_as_of_by_date_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Issues/AsOf(date&#x3D;{date}) | 
*IssuesApi* | [**issues_get_available_properties_by_assetid_and_tenantid**](docs/IssuesApi.md#issues_get_available_properties_by_assetid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Issues/GetAvailableProperties(assetId&#x3D;{assetId}) | Gets the Properties available on this Model
*IssuesApi* | [**issues_get_by_tenantid**](docs/IssuesApi.md#issues_get_by_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Issues | Returns the EntitySet Issues
*IssuesApi* | [**issues_get_single_entity_by_assetmodelid_and_entityid_and_tenantid**](docs/IssuesApi.md#issues_get_single_entity_by_assetmodelid_and_entityid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Issues(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId}) | 
*IssuesApi* | [**issues_patch_by_assetmodelid_and_entityid_and_tenantid**](docs/IssuesApi.md#issues_patch_by_assetmodelid_and_entityid_and_tenantid) | **PATCH** /{region}/aim/odata/{tenantId}/Issues(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId}) | 
*IssuesApi* | [**issues_post_by_tenantid**](docs/IssuesApi.md#issues_post_by_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Issues | Post a new entity to EntitySet Issues
*JobsApi* | [**jobs_add_document_by_assetmodelid_and_entityid_and_tenantid**](docs/JobsApi.md#jobs_add_document_by_assetmodelid_and_entityid_and_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Jobs(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId})/DocumentEntities | Adds a new document to a model entity
*JobsApi* | [**jobs_as_of_by_date_and_tenantid**](docs/JobsApi.md#jobs_as_of_by_date_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Jobs/AsOf(date&#x3D;{date}) | 
*JobsApi* | [**jobs_get_available_properties_by_assetid_and_tenantid**](docs/JobsApi.md#jobs_get_available_properties_by_assetid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Jobs/GetAvailableProperties(assetId&#x3D;{assetId}) | Gets the Properties available on this Model
*JobsApi* | [**jobs_get_by_tenantid**](docs/JobsApi.md#jobs_get_by_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Jobs | Returns the EntitySet Jobs
*JobsApi* | [**jobs_get_single_entity_by_assetmodelid_and_entityid_and_tenantid**](docs/JobsApi.md#jobs_get_single_entity_by_assetmodelid_and_entityid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Jobs(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId}) | 
*JobsApi* | [**jobs_patch_by_assetmodelid_and_entityid_and_tenantid**](docs/JobsApi.md#jobs_patch_by_assetmodelid_and_entityid_and_tenantid) | **PATCH** /{region}/aim/odata/{tenantId}/Jobs(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId}) | 
*JobsApi* | [**jobs_post_by_tenantid**](docs/JobsApi.md#jobs_post_by_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Jobs | Post a new entity to EntitySet Jobs
*LevelsApi* | [**levels_add_document_by_assetmodelid_and_entityid_and_tenantid**](docs/LevelsApi.md#levels_add_document_by_assetmodelid_and_entityid_and_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Levels(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId})/DocumentEntities | Adds a new document to a model entity
*LevelsApi* | [**levels_as_of_by_date_and_tenantid**](docs/LevelsApi.md#levels_as_of_by_date_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Levels/AsOf(date&#x3D;{date}) | 
*LevelsApi* | [**levels_get_available_properties_by_assetid_and_tenantid**](docs/LevelsApi.md#levels_get_available_properties_by_assetid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Levels/GetAvailableProperties(assetId&#x3D;{assetId}) | Gets the Properties available on this Model
*LevelsApi* | [**levels_get_by_tenantid**](docs/LevelsApi.md#levels_get_by_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Levels | Returns the EntitySet Levels
*LevelsApi* | [**levels_get_single_entity_by_assetmodelid_and_entityid_and_tenantid**](docs/LevelsApi.md#levels_get_single_entity_by_assetmodelid_and_entityid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Levels(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId}) | 
*LevelsApi* | [**levels_patch_by_assetmodelid_and_entityid_and_tenantid**](docs/LevelsApi.md#levels_patch_by_assetmodelid_and_entityid_and_tenantid) | **PATCH** /{region}/aim/odata/{tenantId}/Levels(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId}) | 
*LevelsApi* | [**levels_post_by_tenantid**](docs/LevelsApi.md#levels_post_by_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Levels | Post a new entity to EntitySet Levels
*LogsApi* | [**logs_ingest_logs**](docs/LogsApi.md#logs_ingest_logs) | **POST** /{region}/aim/logs/ImportJson | Imports a batch of logs to the central logging service
*ModelFilesApi* | [**model_files_get_file**](docs/ModelFilesApi.md#model_files_get_file) | **GET** /{region}/aim/api/{tenantId}/modelfiles/download/{assetId}/{modelId} | Downloads the model as originally uploaded
*ModelFilesApi* | [**model_files_upload_single_file**](docs/ModelFilesApi.md#model_files_upload_single_file) | **POST** /{region}/aim/api/{tenantId}/modelfiles/upload | A one-stop service for Uploading an IFC model file, creating an asset and Model as required, and initiating processing
*ModelMappingApi* | [**model_mapping_get_by_mappingid_and_tenantid**](docs/ModelMappingApi.md#model_mapping_get_by_mappingid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/ModelMapping({MappingId}) | Get a single Mapping by its key
*ModelMappingApi* | [**model_mapping_get_by_tenantid**](docs/ModelMappingApi.md#model_mapping_get_by_tenantid) | **GET** /{region}/aim/odata/{tenantId}/ModelMapping | Returns the EntitySet ModelMapping
*ModelsApi* | [**models_assign_by_tenantid_and_assetmodelid**](docs/ModelsApi.md#models_assign_by_tenantid_and_assetmodelid) | **POST** /{region}/aim/odata/{tenantId}/Models({AssetModelId})/Roles.Assign | Assigns a user to the given role on the model
*ModelsApi* | [**models_delete_by_assetmodelid_and_tenantid**](docs/ModelsApi.md#models_delete_by_assetmodelid_and_tenantid) | **DELETE** /{region}/aim/odata/{tenantId}/Models({AssetModelId}) | Archive a model for future deletion
*ModelsApi* | [**models_generate_model_mapping_by_assetmodelid_and_targetmodelid_and_tenantid**](docs/ModelsApi.md#models_generate_model_mapping_by_assetmodelid_and_targetmodelid_and_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Models({AssetModelId})/GenerateModelMapping(id&#x3D;{targetModelId}) | Generates a model mappings between two distinct models
*ModelsApi* | [**models_get_by_tenantid**](docs/ModelsApi.md#models_get_by_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Models | Returns the EntitySet Models
*ModelsApi* | [**models_get_single_by_assetmodelid_and_tenantid**](docs/ModelsApi.md#models_get_single_by_assetmodelid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Models({AssetModelId}) | Returns the entity with the key from Models
*ModelsApi* | [**models_member_access_by_assetmodelid_and_tenantid**](docs/ModelsApi.md#models_member_access_by_assetmodelid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Models({AssetModelId})/MemberAccess | Gets the list of users with access to this model and their permissions
*ModelsApi* | [**models_patch_by_assetmodelid_and_tenantid**](docs/ModelsApi.md#models_patch_by_assetmodelid_and_tenantid) | **PATCH** /{region}/aim/odata/{tenantId}/Models({AssetModelId}) | Edit an existing model
*ModelsApi* | [**models_permissions_by_assetmodelid_and_tenantid**](docs/ModelsApi.md#models_permissions_by_assetmodelid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Models({AssetModelId})/Permissions | Gets the effective permissions for the current user
*ModelsApi* | [**models_post_by_tenantid**](docs/ModelsApi.md#models_post_by_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Models | Creates a new Model for the given Asset
*ModelsApi* | [**models_reprocess_by_assetmodelid_and_tenantid**](docs/ModelsApi.md#models_reprocess_by_assetmodelid_and_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Models({AssetModelId})/Reprocess() | Requeues a model for processing and import
*ModelsApi* | [**models_revoke_by_tenantid_and_assetmodelid**](docs/ModelsApi.md#models_revoke_by_tenantid_and_assetmodelid) | **POST** /{region}/aim/odata/{tenantId}/Models({AssetModelId})/Roles.Revoke | Revokes a user from the given role on the model
*ModelsApi* | [**models_roles_by_assetmodelid_and_tenantid**](docs/ModelsApi.md#models_roles_by_assetmodelid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Models({AssetModelId})/Roles | Gets the roles for the given Model
*ModelsApi* | [**models_supercede_by_key_and_tenantid**](docs/ModelsApi.md#models_supercede_by_key_and_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Models({key})/Supercede() | Supercede an existing model with a new version
*ResourcesApi* | [**resources_add_document_by_assetmodelid_and_entityid_and_tenantid**](docs/ResourcesApi.md#resources_add_document_by_assetmodelid_and_entityid_and_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Resources(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId})/DocumentEntities | Adds a new document to a model entity
*ResourcesApi* | [**resources_as_of_by_date_and_tenantid**](docs/ResourcesApi.md#resources_as_of_by_date_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Resources/AsOf(date&#x3D;{date}) | 
*ResourcesApi* | [**resources_get_available_properties_by_assetid_and_tenantid**](docs/ResourcesApi.md#resources_get_available_properties_by_assetid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Resources/GetAvailableProperties(assetId&#x3D;{assetId}) | Gets the Properties available on this Model
*ResourcesApi* | [**resources_get_by_tenantid**](docs/ResourcesApi.md#resources_get_by_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Resources | Returns the EntitySet Resources
*ResourcesApi* | [**resources_get_single_entity_by_assetmodelid_and_entityid_and_tenantid**](docs/ResourcesApi.md#resources_get_single_entity_by_assetmodelid_and_entityid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Resources(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId}) | 
*ResourcesApi* | [**resources_patch_by_assetmodelid_and_entityid_and_tenantid**](docs/ResourcesApi.md#resources_patch_by_assetmodelid_and_entityid_and_tenantid) | **PATCH** /{region}/aim/odata/{tenantId}/Resources(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId}) | 
*ResourcesApi* | [**resources_post_by_tenantid**](docs/ResourcesApi.md#resources_post_by_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Resources | Post a new entity to EntitySet Resources
*SchedulesApi* | [**schedules_get_schedule_by_assetmodelid_and_schedulename_and_tenantid**](docs/SchedulesApi.md#schedules_get_schedule_by_assetmodelid_and_schedulename_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Schedules({AssetModelId},&#39;{ScheduleName}&#39;) | 
*SchedulesApi* | [**schedules_get_schedule_rows_by_assetmodelid_and_schedulename_and_tenantid**](docs/SchedulesApi.md#schedules_get_schedule_rows_by_assetmodelid_and_schedulename_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Schedules({assetModelId},&#39;{scheduleName}&#39;)/Rows | 
*SchedulesApi* | [**schedules_get_schedules_by_tenantid**](docs/SchedulesApi.md#schedules_get_schedules_by_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Schedules | Returns the EntitySet Schedules
*SchedulesApi* | [**schedules_import_schedule_by_modelid_and_schedule_and_tenantid**](docs/SchedulesApi.md#schedules_import_schedule_by_modelid_and_schedule_and_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Schedules/Import(AssetModelId&#x3D;{modelId},ScheduleName&#x3D;&#39;{schedule}&#39;) | 
*SitesApi* | [**sites_add_document_by_assetmodelid_and_entityid_and_tenantid**](docs/SitesApi.md#sites_add_document_by_assetmodelid_and_entityid_and_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Sites(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId})/DocumentEntities | Adds a new document to a model entity
*SitesApi* | [**sites_as_of_by_date_and_tenantid**](docs/SitesApi.md#sites_as_of_by_date_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Sites/AsOf(date&#x3D;{date}) | 
*SitesApi* | [**sites_get_available_properties_by_assetid_and_tenantid**](docs/SitesApi.md#sites_get_available_properties_by_assetid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Sites/GetAvailableProperties(assetId&#x3D;{assetId}) | Gets the Properties available on this Model
*SitesApi* | [**sites_get_by_tenantid**](docs/SitesApi.md#sites_get_by_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Sites | Returns the EntitySet Sites
*SitesApi* | [**sites_get_single_entity_by_assetmodelid_and_entityid_and_tenantid**](docs/SitesApi.md#sites_get_single_entity_by_assetmodelid_and_entityid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Sites(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId}) | 
*SitesApi* | [**sites_patch_by_assetmodelid_and_entityid_and_tenantid**](docs/SitesApi.md#sites_patch_by_assetmodelid_and_entityid_and_tenantid) | **PATCH** /{region}/aim/odata/{tenantId}/Sites(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId}) | 
*SitesApi* | [**sites_post_by_tenantid**](docs/SitesApi.md#sites_post_by_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Sites | Post a new entity to EntitySet Sites
*SpacesApi* | [**spaces_add_document_by_assetmodelid_and_entityid_and_tenantid**](docs/SpacesApi.md#spaces_add_document_by_assetmodelid_and_entityid_and_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Spaces(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId})/DocumentEntities | Adds a new document to a model entity
*SpacesApi* | [**spaces_as_of_by_date_and_tenantid**](docs/SpacesApi.md#spaces_as_of_by_date_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Spaces/AsOf(date&#x3D;{date}) | 
*SpacesApi* | [**spaces_contained_components_by_assetmodelid_and_entityid_and_tenantid**](docs/SpacesApi.md#spaces_contained_components_by_assetmodelid_and_entityid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Spaces(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId})/ContainedComponents | Gets the set of Components which are placed within the Geometry footprint of this Space
*SpacesApi* | [**spaces_get_available_properties_by_assetid_and_tenantid**](docs/SpacesApi.md#spaces_get_available_properties_by_assetid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Spaces/GetAvailableProperties(assetId&#x3D;{assetId}) | Gets the Properties available on this Model
*SpacesApi* | [**spaces_get_by_tenantid**](docs/SpacesApi.md#spaces_get_by_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Spaces | Returns the EntitySet Spaces
*SpacesApi* | [**spaces_get_single_entity_by_assetmodelid_and_entityid_and_tenantid**](docs/SpacesApi.md#spaces_get_single_entity_by_assetmodelid_and_entityid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Spaces(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId}) | 
*SpacesApi* | [**spaces_patch_by_assetmodelid_and_entityid_and_tenantid**](docs/SpacesApi.md#spaces_patch_by_assetmodelid_and_entityid_and_tenantid) | **PATCH** /{region}/aim/odata/{tenantId}/Spaces(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId}) | Edit an existing space
*SpacesApi* | [**spaces_post_by_tenantid**](docs/SpacesApi.md#spaces_post_by_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Spaces | Adds a new Space to a model
*SparesApi* | [**spares_add_document_by_assetmodelid_and_entityid_and_tenantid**](docs/SparesApi.md#spares_add_document_by_assetmodelid_and_entityid_and_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Spares(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId})/DocumentEntities | Adds a new document to a model entity
*SparesApi* | [**spares_as_of_by_date_and_tenantid**](docs/SparesApi.md#spares_as_of_by_date_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Spares/AsOf(date&#x3D;{date}) | 
*SparesApi* | [**spares_get_available_properties_by_assetid_and_tenantid**](docs/SparesApi.md#spares_get_available_properties_by_assetid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Spares/GetAvailableProperties(assetId&#x3D;{assetId}) | Gets the Properties available on this Model
*SparesApi* | [**spares_get_by_tenantid**](docs/SparesApi.md#spares_get_by_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Spares | Returns the EntitySet Spares
*SparesApi* | [**spares_get_single_entity_by_assetmodelid_and_entityid_and_tenantid**](docs/SparesApi.md#spares_get_single_entity_by_assetmodelid_and_entityid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Spares(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId}) | 
*SparesApi* | [**spares_patch_by_assetmodelid_and_entityid_and_tenantid**](docs/SparesApi.md#spares_patch_by_assetmodelid_and_entityid_and_tenantid) | **PATCH** /{region}/aim/odata/{tenantId}/Spares(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId}) | 
*SparesApi* | [**spares_post_by_tenantid**](docs/SparesApi.md#spares_post_by_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Spares | Post a new entity to EntitySet Spares
*StatsApi* | [**stats_metered_resources**](docs/StatsApi.md#stats_metered_resources) | **GET** /{region}/aim/api/{tenantId}/stats/planAllowances | Lists the plan allowances and current consumpttion for a tenant&#39;s app
*StatsApi* | [**stats_rate_limits**](docs/StatsApi.md#stats_rate_limits) | **GET** /{region}/aim/api/{tenantId}/stats/rateLimits | Provides details of the permitted rate limits for tenant&#39;s app and user
*SystemsApi* | [**systems_add_document_by_assetmodelid_and_entityid_and_tenantid**](docs/SystemsApi.md#systems_add_document_by_assetmodelid_and_entityid_and_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Systems(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId})/DocumentEntities | Adds a new document to a model entity
*SystemsApi* | [**systems_as_of_by_date_and_tenantid**](docs/SystemsApi.md#systems_as_of_by_date_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Systems/AsOf(date&#x3D;{date}) | 
*SystemsApi* | [**systems_get_available_properties_by_assetid_and_tenantid**](docs/SystemsApi.md#systems_get_available_properties_by_assetid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Systems/GetAvailableProperties(assetId&#x3D;{assetId}) | Gets the Properties available on this Model
*SystemsApi* | [**systems_get_by_tenantid**](docs/SystemsApi.md#systems_get_by_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Systems | Returns the EntitySet Systems
*SystemsApi* | [**systems_get_single_entity_by_assetmodelid_and_entityid_and_tenantid**](docs/SystemsApi.md#systems_get_single_entity_by_assetmodelid_and_entityid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Systems(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId}) | 
*SystemsApi* | [**systems_patch_by_assetmodelid_and_entityid_and_tenantid**](docs/SystemsApi.md#systems_patch_by_assetmodelid_and_entityid_and_tenantid) | **PATCH** /{region}/aim/odata/{tenantId}/Systems(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId}) | 
*SystemsApi* | [**systems_post_by_tenantid**](docs/SystemsApi.md#systems_post_by_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Systems | Post a new entity to EntitySet Systems
*ThumbnailsApi* | [**thumbnails_get_asset_thumbnail**](docs/ThumbnailsApi.md#thumbnails_get_asset_thumbnail) | **GET** /{region}/aim/api/{tenantId}/thumbnails/asset/{assetId} | 
*ThumbnailsApi* | [**thumbnails_post_asset_thumbnail**](docs/ThumbnailsApi.md#thumbnails_post_asset_thumbnail) | **POST** /{region}/aim/api/{tenantId}/thumbnails/asset/{assetId} | 
*WexbimApi* | [**wexbim_get_complete**](docs/WexbimApi.md#wexbim_get_complete) | **GET** /{region}/aim/api/{tenantId}/wexbim/complete | Gets the Furniture geometry stream for an asset
*WexbimApi* | [**wexbim_get_components**](docs/WexbimApi.md#wexbim_get_components) | **GET** /{region}/aim/api/{tenantId}/wexbim/components | Gets the Furniture geometry stream for an asset
*WexbimApi* | [**wexbim_get_envelope**](docs/WexbimApi.md#wexbim_get_envelope) | **GET** /{region}/aim/api/{tenantId}/wexbim/envelope | Gets the building envelope geometry stream for an asset
*WexbimApi* | [**wexbim_get_envelope_cut**](docs/WexbimApi.md#wexbim_get_envelope_cut) | **GET** /{region}/aim/api/{tenantId}/wexbim/envelopecut | 
*WexbimApi* | [**wexbim_get_envelope_free_cut**](docs/WexbimApi.md#wexbim_get_envelope_free_cut) | **GET** /{region}/aim/api/{tenantId}/wexbim/envelopefreecut | 
*WexbimApi* | [**wexbim_get_site**](docs/WexbimApi.md#wexbim_get_site) | **GET** /{region}/aim/api/{tenantId}/wexbim/site | Gets the site geometry if available
*WexbimApi* | [**wexbim_get_spatial_structure**](docs/WexbimApi.md#wexbim_get_spatial_structure) | **GET** /{region}/aim/api/{tenantId}/wexbim/spatial | Gets the spatial geometry stream for an asset
*WexbimApi* | [**wexbim_get_windows_and_doors**](docs/WexbimApi.md#wexbim_get_windows_and_doors) | **GET** /{region}/aim/api/{tenantId}/wexbim/windowsdoors | Gets the building envelope geometry stream for an asset
*ZonesApi* | [**zones_add_document_by_assetmodelid_and_entityid_and_tenantid**](docs/ZonesApi.md#zones_add_document_by_assetmodelid_and_entityid_and_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Zones(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId})/DocumentEntities | Adds a new document to a model entity
*ZonesApi* | [**zones_as_of_by_date_and_tenantid**](docs/ZonesApi.md#zones_as_of_by_date_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Zones/AsOf(date&#x3D;{date}) | 
*ZonesApi* | [**zones_get_available_properties_by_assetid_and_tenantid**](docs/ZonesApi.md#zones_get_available_properties_by_assetid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Zones/GetAvailableProperties(assetId&#x3D;{assetId}) | Gets the Properties available on this Model
*ZonesApi* | [**zones_get_by_tenantid**](docs/ZonesApi.md#zones_get_by_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Zones | Returns the EntitySet Zones
*ZonesApi* | [**zones_get_single_entity_by_assetmodelid_and_entityid_and_tenantid**](docs/ZonesApi.md#zones_get_single_entity_by_assetmodelid_and_entityid_and_tenantid) | **GET** /{region}/aim/odata/{tenantId}/Zones(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId}) | 
*ZonesApi* | [**zones_patch_by_assetmodelid_and_entityid_and_tenantid**](docs/ZonesApi.md#zones_patch_by_assetmodelid_and_entityid_and_tenantid) | **PATCH** /{region}/aim/odata/{tenantId}/Zones(AssetModelId&#x3D;{assetModelId}, EntityId&#x3D;{entityId}) | 
*ZonesApi* | [**zones_post_by_tenantid**](docs/ZonesApi.md#zones_post_by_tenantid) | **POST** /{region}/aim/odata/{tenantId}/Zones | Post a new entity to EntitySet Zones


## Documentation For Models

 - [Application](docs/Application.md)
 - [AssemblyDiagnostics](docs/AssemblyDiagnostics.md)
 - [AssemblyInfo](docs/AssemblyInfo.md)
 - [AssemblyItem](docs/AssemblyItem.md)
 - [Asset](docs/Asset.md)
 - [AssetCreate](docs/AssetCreate.md)
 - [AssetSegment](docs/AssetSegment.md)
 - [AttributeDefinition](docs/AttributeDefinition.md)
 - [AttributeDefinitionCreate](docs/AttributeDefinitionCreate.md)
 - [AttributeDefinitionEdit](docs/AttributeDefinitionEdit.md)
 - [AttributeDefinitionEntity](docs/AttributeDefinitionEntity.md)
 - [AttributeValue](docs/AttributeValue.md)
 - [AttributeValueEntity](docs/AttributeValueEntity.md)
 - [Cell](docs/Cell.md)
 - [ClassificationNode](docs/ClassificationNode.md)
 - [ColumnDefinition](docs/ColumnDefinition.md)
 - [ComplexValueBase](docs/ComplexValueBase.md)
 - [Component](docs/Component.md)
 - [ComponentCreate](docs/ComponentCreate.md)
 - [ComponentEdit](docs/ComponentEdit.md)
 - [ComponentInfo](docs/ComponentInfo.md)
 - [ComponentType](docs/ComponentType.md)
 - [ComponentTypeInfo](docs/ComponentTypeInfo.md)
 - [Contact](docs/Contact.md)
 - [ContactEntity](docs/ContactEntity.md)
 - [ContactInfo](docs/ContactInfo.md)
 - [DbUpdate](docs/DbUpdate.md)
 - [Document](docs/Document.md)
 - [DocumentCreate](docs/DocumentCreate.md)
 - [DocumentInfo](docs/DocumentInfo.md)
 - [Entity](docs/Entity.md)
 - [EntityBase](docs/EntityBase.md)
 - [EntityContact](docs/EntityContact.md)
 - [EntityCreate](docs/EntityCreate.md)
 - [EntityEdit](docs/EntityEdit.md)
 - [EntityMappingInfo](docs/EntityMappingInfo.md)
 - [EntityMatchDescriptor](docs/EntityMatchDescriptor.md)
 - [EntityMatchInfo](docs/EntityMatchInfo.md)
 - [EntityRef](docs/EntityRef.md)
 - [Facility](docs/Facility.md)
 - [FacilityInfo](docs/FacilityInfo.md)
 - [FileUploadResult](docs/FileUploadResult.md)
 - [Footprint](docs/Footprint.md)
 - [IMeteredResource](docs/IMeteredResource.md)
 - [IfcType](docs/IfcType.md)
 - [InlineObject2](docs/InlineObject2.md)
 - [InlineObject3](docs/InlineObject3.md)
 - [InlineObject4](docs/InlineObject4.md)
 - [InlineObject5](docs/InlineObject5.md)
 - [InlineObject6](docs/InlineObject6.md)
 - [Issue](docs/Issue.md)
 - [IssueInfo](docs/IssueInfo.md)
 - [Job](docs/Job.md)
 - [JobCreate](docs/JobCreate.md)
 - [JobEdit](docs/JobEdit.md)
 - [JobInfo](docs/JobInfo.md)
 - [Level](docs/Level.md)
 - [LevelCreate](docs/LevelCreate.md)
 - [LevelEdit](docs/LevelEdit.md)
 - [LevelInfo](docs/LevelInfo.md)
 - [MappingMessageInfo](docs/MappingMessageInfo.md)
 - [MappingProperties](docs/MappingProperties.md)
 - [MemberPermission](docs/MemberPermission.md)
 - [MemberRole](docs/MemberRole.md)
 - [Model](docs/Model.md)
 - [ModelCreate](docs/ModelCreate.md)
 - [ModelEdit](docs/ModelEdit.md)
 - [ModelInfo](docs/ModelInfo.md)
 - [ModelMapping](docs/ModelMapping.md)
 - [ModelMappingReport](docs/ModelMappingReport.md)
 - [ODataListResponseOfApplication](docs/ODataListResponseOfApplication.md)
 - [ODataListResponseOfAssemblyDiagnostics](docs/ODataListResponseOfAssemblyDiagnostics.md)
 - [ODataListResponseOfAssemblyItem](docs/ODataListResponseOfAssemblyItem.md)
 - [ODataListResponseOfAsset](docs/ODataListResponseOfAsset.md)
 - [ODataListResponseOfAttributeDefinition](docs/ODataListResponseOfAttributeDefinition.md)
 - [ODataListResponseOfAttributeDefinitionEntity](docs/ODataListResponseOfAttributeDefinitionEntity.md)
 - [ODataListResponseOfAttributeValue](docs/ODataListResponseOfAttributeValue.md)
 - [ODataListResponseOfComplexValueBase](docs/ODataListResponseOfComplexValueBase.md)
 - [ODataListResponseOfComponent](docs/ODataListResponseOfComponent.md)
 - [ODataListResponseOfComponentType](docs/ODataListResponseOfComponentType.md)
 - [ODataListResponseOfContact](docs/ODataListResponseOfContact.md)
 - [ODataListResponseOfDocument](docs/ODataListResponseOfDocument.md)
 - [ODataListResponseOfEntity](docs/ODataListResponseOfEntity.md)
 - [ODataListResponseOfEntityRef](docs/ODataListResponseOfEntityRef.md)
 - [ODataListResponseOfFacility](docs/ODataListResponseOfFacility.md)
 - [ODataListResponseOfIssue](docs/ODataListResponseOfIssue.md)
 - [ODataListResponseOfJob](docs/ODataListResponseOfJob.md)
 - [ODataListResponseOfLevel](docs/ODataListResponseOfLevel.md)
 - [ODataListResponseOfMemberPermission](docs/ODataListResponseOfMemberPermission.md)
 - [ODataListResponseOfModel](docs/ODataListResponseOfModel.md)
 - [ODataListResponseOfModelMapping](docs/ODataListResponseOfModelMapping.md)
 - [ODataListResponseOfModelMappingReport](docs/ODataListResponseOfModelMappingReport.md)
 - [ODataListResponseOfResource](docs/ODataListResponseOfResource.md)
 - [ODataListResponseOfRole](docs/ODataListResponseOfRole.md)
 - [ODataListResponseOfRow](docs/ODataListResponseOfRow.md)
 - [ODataListResponseOfSchedule](docs/ODataListResponseOfSchedule.md)
 - [ODataListResponseOfSite](docs/ODataListResponseOfSite.md)
 - [ODataListResponseOfSpace](docs/ODataListResponseOfSpace.md)
 - [ODataListResponseOfSpare](docs/ODataListResponseOfSpare.md)
 - [ODataListResponseOfSystemItem](docs/ODataListResponseOfSystemItem.md)
 - [ODataListResponseOfZone](docs/ODataListResponseOfZone.md)
 - [ODataResponseOfBoolean](docs/ODataResponseOfBoolean.md)
 - [QuotaStatus](docs/QuotaStatus.md)
 - [RelatedEntity](docs/RelatedEntity.md)
 - [Resource](docs/Resource.md)
 - [ResourceInfo](docs/ResourceInfo.md)
 - [Role](docs/Role.md)
 - [RoleMember](docs/RoleMember.md)
 - [Row](docs/Row.md)
 - [Schedule](docs/Schedule.md)
 - [Site](docs/Site.md)
 - [Space](docs/Space.md)
 - [SpaceCreate](docs/SpaceCreate.md)
 - [SpaceEdit](docs/SpaceEdit.md)
 - [SpaceInfo](docs/SpaceInfo.md)
 - [Spare](docs/Spare.md)
 - [SpareCreate](docs/SpareCreate.md)
 - [SpareEdit](docs/SpareEdit.md)
 - [SpareInfo](docs/SpareInfo.md)
 - [SystemInfo](docs/SystemInfo.md)
 - [SystemItem](docs/SystemItem.md)
 - [UserPermissions](docs/UserPermissions.md)
 - [ValueContainer](docs/ValueContainer.md)
 - [Zone](docs/Zone.md)
 - [ZoneInfo](docs/ZoneInfo.md)


## Documentation For Authorization


## oauth2

- **Type**: OAuth
- **Flow**: implicit
- **Authorization URL**: https://internal.xbim-dev.net/id/connect/authorize
- **Scopes**: 
 - **api.read**: Read-only access to Asset data
 - **api.write**: Manage your Asset data
 - **api.admin**: Administer the API


## Author

info@xbim.net


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in aim.apis and aim.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from xbim_flex.aim.api.default_api import DefaultApi`
- `from xbim_flex.aim.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import xbim_flex.aim
from xbim_flex.aim.apis import *
from xbim_flex.aim.models import *
```

